<!--
Copyright 2022 Tecton, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->
# airflow-tecton

Contains an Apache Airflow provider to be used with Tecton.

This enables you to use Airflow to submit jobs as well as wait for materialization to complete.

## Run unit tests

Run `python -m pytest tests/` in the repo root.
